@@ -185,12 +185,9 @@ argparse._SubParsersAction.add_parser = _add_parser
 class ConfArgParser(argparse.ArgumentParser):
     def __init__(self, *args, **kwargs):
         self.section = kwargs.get("section", "defaults")
-        self.callback = kwargs.get("callback", lambda opt: True)
 
         if "section" in kwargs:
             del kwargs["section"]
-        if "callback" in kwargs:
-            del kwargs["callback"]
 
         ckwargs = dict(kwargs)
         ckwargs["add_help"] = False
@@ -326,11 +323,8 @@ class ConfArgParser(argparse.ArgumentParser):
         if args.conf_file:
             config = ConfigParser.SafeConfigParser()
             config.read(args.conf_file)
-            while True:
-                config_options = self.config2dest(config)
-                namespace = argparse.Namespace(**config_options)
-                if self.callback(self, namespace):
-                    break
+            config_options = self.config2dest(config)
+            namespace = argparse.Namespace(**config_options)
             self.set_defaults(**config_options)
         if args.export_conf_file:
             self.args2config(remaining_argv).write(args.export_conf_file)
@@ -348,4 +342,4 @@ class ConfArgParser(argparse.ArgumentParser):
         if not self._subparsers:
             args = self._parse_config(args)
         return argparse.ArgumentParser.parse_args(self, args, namespace)
-   
+
